.. _collisions:

********************************************
Collisions (`plasmapy.formulary.collisions`)
********************************************

.. currentmodule:: plasmapy.formulary.collisions

.. automodapi:: plasmapy.formulary.collisions

Examples
========

.. nbgallery::
    :caption: Examples

    /notebooks/formulary/coulomb
